window.Gleam.initSearch([{"doc":"gleam_fetch","title":"gleam_fetch","content":"# Fetch\n\n&lt;a href=&quot;https://github.com/gleam-lang/fetch/releases&quot;&gt;&lt;img src=&quot;https://img.shields.io/github/release/gleam-lang/fetch&quot; alt=&quot;GitHub release&quot;&gt;&lt;/a&gt;\n&lt;a href=&quot;https://discord.gg/Fm8Pwmy&quot;&gt;&lt;img src=&quot;https://img.shields.io/discord/768594524158427167?color=blue&quot; alt=&quot;Discord chat&quot;&gt;&lt;/a&gt;\n![test](https://github.com/gleam-lang/fetch/workflows/test/badge.svg?branch=main)\n\nBindings to JavaScript&#39;s built in HTTP client, `fetch`.\n\nIf you are running your Gleam project on the Erlang target (the default\nfor new Gleam projects) then you will want to use a different library\nwhich can run on Erlang, such as [gleam_httpc](https://github.com/gleam-lang/httpc).\n\n```gleam\nimport gleam/fetch\nimport gleam/http/request\nimport gleam/http/response\nimport gleam/javascript/promise\n\npub fn main() {\n  let assert Ok(req) = request.to(&quot;https://example.com&quot;)\n\n  // Send the HTTP request to the server\n  use resp &lt;- promise.try_await(fetch.send(req))\n  use resp &lt;- promise.try_await(fetch.read_text_body(resp))\n\n  // We get a response record back\n  resp.status\n  // -&gt; 200\n\n  response.get_header(resp, &quot;content-type&quot;)\n  // -&gt; Ok(&quot;text/html; charset=UTF-8&quot;)\n\n  promise.resolve(Ok(Nil))\n}\n```\n","url":"index.html"},{"doc":"gleam/fetch/form_data","title":"FormData","content":"pub type FormData\n\n\nSynonyms:\ngleam/fetch/form_data.FormData\ngleam/fetch/form_data FormData","url":"gleam/fetch/form_data.html#FormData"},{"doc":"gleam/fetch/form_data","title":"append","content":"pub fn append(\n  form_data: FormData,\n  key: String,\n  value: String,\n) -&gt; FormData\n\nSynonyms:\ngleam/fetch/form_data.append\ngleam/fetch/form_data append","url":"gleam/fetch/form_data.html#append"},{"doc":"gleam/fetch/form_data","title":"append_bits","content":"pub fn append_bits(\n  form_data: FormData,\n  key: String,\n  value: BitArray,\n) -&gt; FormData\n\nSynonyms:\ngleam/fetch/form_data.append_bits\ngleam/fetch/form_data append_bits","url":"gleam/fetch/form_data.html#append_bits"},{"doc":"gleam/fetch/form_data","title":"new","content":"pub fn new() -&gt; FormData\n\nSynonyms:\ngleam/fetch/form_data.new\ngleam/fetch/form_data new","url":"gleam/fetch/form_data.html#new"},{"doc":"gleam/fetch/form_data","title":"set","content":"pub fn set(\n  form_data: FormData,\n  key: String,\n  value: String,\n) -&gt; FormData\n\nSynonyms:\ngleam/fetch/form_data.set\ngleam/fetch/form_data set","url":"gleam/fetch/form_data.html#set"},{"doc":"gleam/fetch/form_data","title":"set_bits","content":"pub fn set_bits(\n  form_data: FormData,\n  key: String,\n  value: BitArray,\n) -&gt; FormData\n\nSynonyms:\ngleam/fetch/form_data.set_bits\ngleam/fetch/form_data set_bits","url":"gleam/fetch/form_data.html#set_bits"},{"doc":"gleam/fetch/form_data","title":"gleam/fetch/form_data","content":"","url":"gleam/fetch/form_data.html"},{"doc":"gleam/fetch","title":"FetchBody","content":"pub type FetchBody\n\n\nSynonyms:\ngleam/fetch.FetchBody\ngleam/fetch FetchBody","url":"gleam/fetch.html#FetchBody"},{"doc":"gleam/fetch","title":"FetchError","content":"pub type FetchError {\n  NetworkError(String)\n  UnableToReadBody\n  InvalidJsonBody\n}\n\nNetworkError(String)\n\n\nUnableToReadBody\n\n\nInvalidJsonBody\n\n\nSynonyms:\ngleam/fetch.FetchError\ngleam/fetch FetchError","url":"gleam/fetch.html#FetchError"},{"doc":"gleam/fetch","title":"FetchRequest","content":"pub type FetchRequest\n\n\nSynonyms:\ngleam/fetch.FetchRequest\ngleam/fetch FetchRequest","url":"gleam/fetch.html#FetchRequest"},{"doc":"gleam/fetch","title":"FetchResponse","content":"pub type FetchResponse\n\n\nSynonyms:\ngleam/fetch.FetchResponse\ngleam/fetch FetchResponse","url":"gleam/fetch.html#FetchResponse"},{"doc":"gleam/fetch","title":"bitarray_request_to_fetch_request","content":"pub fn bitarray_request_to_fetch_request(\n  a: Request(BitArray),\n) -&gt; FetchRequest\n\nSynonyms:\ngleam/fetch.bitarray_request_to_fetch_request\ngleam/fetch bitarray_request_to_fetch_request","url":"gleam/fetch.html#bitarray_request_to_fetch_request"},{"doc":"gleam/fetch","title":"form_data_to_fetch_request","content":"pub fn form_data_to_fetch_request(\n  a: Request(FormData),\n) -&gt; FetchRequest\n\nSynonyms:\ngleam/fetch.form_data_to_fetch_request\ngleam/fetch form_data_to_fetch_request","url":"gleam/fetch.html#form_data_to_fetch_request"},{"doc":"gleam/fetch","title":"from_fetch_response","content":"pub fn from_fetch_response(\n  a: FetchResponse,\n) -&gt; Response(FetchBody)\n\nSynonyms:\ngleam/fetch.from_fetch_response\ngleam/fetch from_fetch_response","url":"gleam/fetch.html#from_fetch_response"},{"doc":"gleam/fetch","title":"raw_send","content":"pub fn raw_send(\n  a: FetchRequest,\n) -&gt; Promise(Result(FetchResponse, FetchError))\n\nSynonyms:\ngleam/fetch.raw_send\ngleam/fetch raw_send","url":"gleam/fetch.html#raw_send"},{"doc":"gleam/fetch","title":"read_bytes_body","content":"pub fn read_bytes_body(\n  a: Response(FetchBody),\n) -&gt; Promise(Result(Response(BitArray), FetchError))\n\nSynonyms:\ngleam/fetch.read_bytes_body\ngleam/fetch read_bytes_body","url":"gleam/fetch.html#read_bytes_body"},{"doc":"gleam/fetch","title":"read_json_body","content":"pub fn read_json_body(\n  a: Response(FetchBody),\n) -&gt; Promise(Result(Response(Dynamic), FetchError))\n\nSynonyms:\ngleam/fetch.read_json_body\ngleam/fetch read_json_body","url":"gleam/fetch.html#read_json_body"},{"doc":"gleam/fetch","title":"read_text_body","content":"pub fn read_text_body(\n  a: Response(FetchBody),\n) -&gt; Promise(Result(Response(String), FetchError))\n\nSynonyms:\ngleam/fetch.read_text_body\ngleam/fetch read_text_body","url":"gleam/fetch.html#read_text_body"},{"doc":"gleam/fetch","title":"send","content":"pub fn send(\n  request: Request(String),\n) -&gt; Promise(Result(Response(FetchBody), FetchError))\n\nSynonyms:\ngleam/fetch.send\ngleam/fetch send","url":"gleam/fetch.html#send"},{"doc":"gleam/fetch","title":"send_bits","content":"pub fn send_bits(\n  request: Request(BitArray),\n) -&gt; Promise(Result(Response(FetchBody), FetchError))\n\nSynonyms:\ngleam/fetch.send_bits\ngleam/fetch send_bits","url":"gleam/fetch.html#send_bits"},{"doc":"gleam/fetch","title":"send_form_data","content":"pub fn send_form_data(\n  request: Request(FormData),\n) -&gt; Promise(Result(Response(FetchBody), FetchError))\n\nSynonyms:\ngleam/fetch.send_form_data\ngleam/fetch send_form_data","url":"gleam/fetch.html#send_form_data"},{"doc":"gleam/fetch","title":"to_fetch_request","content":"pub fn to_fetch_request(a: Request(String)) -&gt; FetchRequest\n\nSynonyms:\ngleam/fetch.to_fetch_request\ngleam/fetch to_fetch_request","url":"gleam/fetch.html#to_fetch_request"},{"doc":"gleam/fetch","title":"gleam/fetch","content":"","url":"gleam/fetch.html"}]);